@@ -9,7 +9,7 @@ fi
 
 cleanup()
 {
-	echo "cleaning up"
+	echo "restoring volume"
 	#restore volume
 	pasr --restore < /tmp/evilalarm_sinkstate.backup
 	rm /tmp/evilalarm_sinkstate.backup
@@ -23,16 +23,20 @@ trap "cleanup" 0
 #no, directly running cleanup() in the first trap doesn't work. 0 needs to be trapped.
 
 
+#stop media player to stop it from interfering with audio playback (pause isn't enough)
+dbus-send --dest=com.nokia.mafw.renderer.Mafw-Gst-Renderer-Plugin.gstrenderer /com/nokia/mafw/renderer/gstrenderer com.nokia.mafw.renderer.stop
+
+
 #save current volume
 pasr --store > /tmp/evilalarm_sinkstate.backup
 
 while true;
 do
-	ps | grep -v keepvolume | grep evilalarm
+	#don't keep running when evilalarm dies/is killed
+	ps | grep evilalarm | egrep -v 'grep|keep' > /dev/null
 	if [ $? -ne 0 ]
 	then
-		#no evilalarm process found, abort
-		echo "no evilalarm found!"
+		echo "keepvolume.sh: no evilalarm process found!"
 		exit 0
 	fi
 
