@@ -1,19 +1,21 @@
-
+#include "alarm.h"
 #include "module_list.h"
 #include "module_settings.h"
 #include "modules/alarm_blubbels.h"
 #include "modules/alarm_blubbels_settings.h"
+#include "modules/alarm_normal.h"
 #include "modules/alarm_movement.h"
 #include "modules/alarm_movement_settings.h"
 
 
-//get the user-configured module
 Alarm* ModuleList::getModuleInstance(QWidget *parent)
 {
 	QSettings settings;
 	QString modulename = settings.value("module").toString().toLower();
 
-	if(modulename == "movement")
+	if(modulename == "normal")
+		return new AlarmNormal(parent);
+	else if(modulename == "movement")
 		return new AlarmMovement(parent);
 	else if(modulename == "blubbels")
 		return new AlarmBlubbels(parent);
@@ -21,7 +23,6 @@ Alarm* ModuleList::getModuleInstance(QWidget *parent)
 		return new AlarmMovement(parent);
 }
 
-//get a settings widget for the given module name
 ModuleSettings* ModuleList::getSettingsInstance(QString name, QWidget *parent)
 {
 	name = name.toLower();
@@ -35,5 +36,5 @@ ModuleSettings* ModuleList::getSettingsInstance(QString name, QWidget *parent)
 
 QStringList ModuleList::availableModules()
 {
-	return QStringList() << "Blubbels" << "Movement";
+	return QStringList() << "Normal" << "Blubbels" << "Movement";
 }
