@@ -15,16 +15,11 @@ Accelerometer::Accelerometer(QObject *parent, int interval):
 		this, SLOT(tick()));
 	timer->setInterval(interval);
 	timer->start();
-	/*
-	QDBusConnection::systemBus().call(QDBusMessage::createMethodCall(MCE_SERVICE, MCE_REQUEST_PATH, MCE_REQUEST_IF, MCE_DEVICE_ORIENTATION_GET));
-	QDBusConnection::systemBus().connect("", MCE_SIGNAL_PATH, MCE_SIGNAL_IF, QString(), this, SLOT(orientationUpdate(QString, QString, QString, int, int, int)));
-	*/
 }
 
 
 Accelerometer::~Accelerometer()
 {
-//	 QDBusConnection::systemBus().disconnect("", MCE_SIGNAL_PATH, MCE_SIGNAL_IF, MCE_DEVICE_ORIENTATION_SIG, this, SLOT(orientationUpdate(QString,QString,QString, int, int, int)));
 	QDBusConnection::systemBus().call(QDBusMessage::createMethodCall(MCE_SERVICE, MCE_REQUEST_PATH, MCE_REQUEST_IF, MCE_ACCELEROMETER_DISABLE_REQ));
 }
 
